@@ -10,7 +10,7 @@
 #' title: "Brain Data"
 #' output: pdf_document
 #' author: ""
-#' date: Requires "care" version 1.1.1 (July 2011) or later
+#' date: Requires "care" version 1.1.7 (November 2014) or later
 #' ---
 
 
@@ -31,11 +31,11 @@ y = lu2004$y # age
 dim(x) 
 # /* 30 403 */
 
-#' Regularization parameters used to fit linear model:
+#' Regularization parameters used to fit linear models:
 reg = slm(x,y)$regularization
 # /* 0.1373 and 0.0246 */
-lambda = reg[1] # correlation shrinkage 
-lambda.var = reg[2] # variance shrinkage 
+lambda = reg[1,"lambda"] # correlation shrinkage 
+lambda.var = reg[1, "lambda.var"] # variance shrinkage 
 
 #' Compute CAR scores to rank predictors: 
 car = carscore(x, y, lambda=lambda)
@@ -46,13 +46,13 @@ ocar[1:30]
 numpred =  c(seq(5, 45, by=10), seq(53, 403, by=25))
 numpred
 car.predlist = make.predlist(ocar, numpred, name="CAR")
-car.models = slm.models(x, y, car.predlist, lambda=lambda, lambda.var=lambda.var)
+car.models = slm(x, y, car.predlist, lambda=lambda, lambda.var=lambda.var)
 
 #' For comparison, use marginal correlations to rank predictors:
 marg = carscore(x, y, lambda=lambda, diagonal=TRUE) # shrinking not actually reqired
 omarg = order(marg^2, decreasing=TRUE)
 marg.predlist = make.predlist(omarg, numpred, name="MARG")
-marg.models = slm.models(x, y, marg.predlist, lambda=lambda, lambda.var=lambda.var)
+marg.models = slm(x, y, marg.predlist, lambda=lambda, lambda.var=lambda.var)
 
 #' Plot model fitted $R^2$ for all models comparing marginal correlation with CAR scores:
 #+ fig.width=8, fig.height=8
@@ -65,6 +65,7 @@ points(marg.models$numpred, marg.models$R2, col=2, type="b")
 legend("bottomright", c("CAR Score", "Marginal Correlation"), col=c(1,2), lty=c(1,1) )
 
 
+#' \newpage
 #'
 #' # Estimate prediction error by crossvalidation
 
@@ -87,8 +88,8 @@ predfun = function(Xtrain, Ytrain, Xtest, Ytest, numVars)
   selVars = ocar[1:numVars]
 
   # fit and predict
-  slm.fit = slm(Xtrain[, selVars, drop=FALSE], Ytrain, verbose=FALSE)
-  Ynew = predict(slm.fit, Xtest[, selVars, drop=FALSE], verbose=FALSE)
+  slm.fit = slm(Xtrain, Ytrain, predlist=list(selVars), verbose=FALSE)
+  Ynew = predict(slm.fit, Xtest, verbose=FALSE)
 
   # compute squared error risk
   mse = mean( (Ynew - Ytest)^2)  
@@ -99,14 +100,14 @@ predfun = function(Xtrain, Ytrain, Xtest, Ytest, numVars)
 #' Compute results from Table 9 in Zuber and Strimmer (2011):
 set.seed(12345)
 cvp = crossval(predfun, xs, ys, K=K, B=B, numVars = 36, verbose=FALSE)
-c(cvp$stat, cvp$stat.se) # 0.3441316  0.007449175
+c(cvp$stat, cvp$stat.se) # 0.3441  0.0074
 set.seed(12345)
 cvp = crossval(predfun, xs, ys, K=K, B=B, numVars = 60, verbose=FALSE)
-c(cvp$stat, cvp$stat.se) # 0.3085344  0.006405896
+c(cvp$stat, cvp$stat.se) # 0.3129  0.0066
 set.seed(12345)
 cvp = crossval(predfun, xs, ys, K=K, B=B, numVars = 85, verbose=FALSE)
-c(cvp$stat, cvp$stat.se) # 0.297824   0.006178467 
-
+c(cvp$stat, cvp$stat.se) # 0.2978  0.0062 
+  
 
 #' This produces Figure 3 in Zuber and Strimmer (2011)
 numpred = c(seq(10, 200, 10), 403) # number of predictors
